@@ -146,8 +146,10 @@ def StartMeasurement():
         if(data.OfflineMode=="True"): #change to offline mode
             cmd="dbus-send --system --dest=com.nokia.mce --type=method_call /com/nokia/mce/request com.nokia.mce.request.req_device_mode_change string:\"offline\""
             os.popen(cmd)
+        data.Xscale=1 #default zoom level
     else:  
         interval=10 #Fast mode for testing
+        data.Xscale=0 #max zoom level
     
     data.run=1
     app.timer_GetData = QtCore.QTimer()
@@ -155,10 +157,11 @@ def StartMeasurement():
     app.timer_GetData.start(interval) 
    
     data.ChangesInGraph=1 #Make sure it only gets refreshed once    
+    RecordWindowGraph.update() #show RecordWindowGraph        
+    RecordWindow.UpdateScreen()    
     
     StartLogfile(interval)
         
-    data.Xscale=1 #default zoom level
     
     print "Start timers (Interval:", interval ,"ms)..."
     print "Sampling interval:", interval, "ms"
@@ -252,7 +255,7 @@ class frmStartWindow(QMainWindow):
     def __init__(self):
         QMainWindow.__init__(self)
         # This attribute makes the whole Stacked Window thing work
-        self.setAttribute(Qt.WA_Maemo5StackedWindow)
+        if(data.demo==0): self.setAttribute(Qt.WA_Maemo5StackedWindow)
         self.ui = Ui_StartWindow()
         self.ui.setupUi(self)
 
@@ -391,7 +394,7 @@ class frmRecordWindow(QMainWindow):
         # Notice that you must give a parent window as parameter to the constuctor
         QMainWindow.__init__(self, parent)
         # Also set the Stacked Window parameter for every subwindow in the stack
-        self.setAttribute(Qt.WA_Maemo5StackedWindow)
+        if(data.demo==0): self.setAttribute(Qt.WA_Maemo5StackedWindow)
         
         self.ui = Ui_RecordWindow()
         self.ui.setupUi(self)
@@ -544,7 +547,7 @@ class frmViewWindow(QMainWindow):
         # Notice that you must give a parent window as parameter to the constuctor
         QMainWindow.__init__(self, parent)
         # Also set the Stacked Window parameter for every subwindow in the stack
-        self.setAttribute(Qt.WA_Maemo5StackedWindow)
+        if(data.demo==0): self.setAttribute(Qt.WA_Maemo5StackedWindow)
         
         
         self.ui = Ui_ViewWindow()
@@ -583,21 +586,25 @@ class frmViewWindow(QMainWindow):
     def UpdateScreen(self):
         shortfolder=string.replace(data.logfolder, "/home/user/MyDocs", "~")
         self.ui.lblLogfile.setText(data.logfilename+" (in "+shortfolder+")")
-        self.ui.lblStarttime.setText("Start: "+str(data.arrData[0][0]))
-        self.ui.lblStoptime.setText("End: "+str(data.arrData[0][data.arrDataIndex-1]))
+#        self.ui.lblStarttime.setText("Start: "+str(data.arrData[0][0]))
+#        self.ui.lblStoptime.setText("End: "+str(data.arrData[0][data.arrDataIndex-1]))
 #        self.ui.lblTrigger.setText(str(data.trigger))
 #        self.ui.lblYscale.setText(str(data.Yscale))
-        self.ui.lblNote.setText(str(data.Note))
         
-        try:
-            t0=time.strptime("2000-1-1 "+str(data.arrData[0][0]), "%Y-%m-%d %H:%M:%S")
-            t1=time.strptime("2000-1-1 "+str(data.arrData[0][data.arrDataIndex-1]), "%Y-%m-%d %H:%M:%S")
-            t0=time.mktime(t0)
-            t1=time.mktime(t1)
-            t=strftime("%H:%M:%S", time.gmtime(t1-t0))
-        except:
-            t="??"
-        self.ui.lblDuration.setText("Duration: "+str(t))
+#        try:
+        start=str(data.StartDate)+" "+str(data.arrData[0][0])
+        stop=str(data.arrData[0][data.arrDataIndex-1])
+        t0=time.strptime(start, "%d-%m-%Y %H:%M:%S")
+        t1=time.strptime("01-01-2000 "+stop, "%d-%m-%Y %H:%M:%S")
+        tt0=time.mktime(t0)
+        tt1=time.mktime(t1)
+        dt=strftime("%H:%M:%S", time.gmtime(tt1-tt0))
+        day=strftime("%A", time.gmtime(tt0))
+            
+            
+        self.ui.lblTimes.setText("Start: "+str(day)+" "+str(data.arrData[0][0])+"   End: "+str(data.arrData[0][data.arrDataIndex-1])+"   Duration: "+str(dt))
+       
+        self.ui.lblNote.setText(str(data.Note))
 
         if(data.Xscale==0): self.ui.bZoomIn.setEnabled(False)
         else: self.ui.bZoomIn.setEnabled(True)
@@ -766,7 +773,7 @@ class frmConfigWindow(QMainWindow):
         # Notice that you must give a parent window as parameter to the constuctor
         QMainWindow.__init__(self, parent)
         # Also set the Stacked Window parameter for every subwindow in the stack
-        self.setAttribute(Qt.WA_Maemo5StackedWindow)
+        if(data.demo==0): self.setAttribute(Qt.WA_Maemo5StackedWindow)
         
         self.ui = Ui_ConfigWindow()
         self.ui.setupUi(self)
