@@ -114,14 +114,14 @@ def OpenLogFile():
         data.Header=file.readline()
         print "Header:",  data.Header
         h=string.split(data.Header, ", ")
-        v=h[4]
-        SWversion=string.replace(v, "SW version:",  "")
+        x=h[4] #SW version
+        SWversion=string.replace(x, "SW version:",  "")
         try:
             fl=float(SWversion)
         except:
             print "SW Version format not valid:",  SWversion
             fl=0.0
-#        print v,  fl,  data.version
+#        print x,  fl,  data.version
         if(fl>1.1 and fl!=213.1321): #log files newer than SW version 1.1. and not Demo version have a new line with notes
 #            print "SW version > 1.1, contains Note"
             data.Note=file.readline()
@@ -129,10 +129,14 @@ def OpenLogFile():
             data.Note=string.replace(data.Note, "\n",  "")
         else:
             data.Note=""
-            data.Header=string.replace(data.Header,  v,  "SW version: "+str(data.version))
+            data.Header=string.replace(data.Header,  x,  "SW version: "+str(data.version))
 #            print "New header:",  data.Header
         print "Note:",  data.Note
             
+            
+        x=h[5] #Date
+        data.StartDate=string.replace(x, "Date: ",  "")
+            
         
         for line in file:
 #            print line
